@@ -27,6 +27,7 @@ from pathlib import Path
 from threading import Event, Thread
 from queue import Queue, Empty
 from traceback import print_exc
+import os
 
 # Non-standard imports
 from tqdm import tqdm
@@ -34,6 +35,27 @@ import oclock
 from clivo import CommandLineInterface as ClI
 
 
+# ================================ MISC Tools ================================
+
+
+def try_thread(function):
+    """Decorator to make threaded functions return & print errors if errors occur"""
+    def wrapper(*args, **kwargs):
+        try:
+            function(*args, **kwargs)
+        except Exception as e:
+            _, name = args
+            nmax, _ = os.get_terminal_size()
+            print('\n')
+            print('=' * nmax)
+            print(f'ERROR for {function.__name__} recording stopped for {name}')
+            print('-' * nmax)
+            print_exc()
+            print('=' * nmax)
+            print('\n')
+            return
+    return wrapper
+
 
 # ========================== Sensor base classes =============================
 
@@ -388,6 +410,7 @@ class RecordBase:
 
     # =========================== Data acquisition ===========================
 
+    @try_thread
     def data_read(self, name):
         """Read data from sensor and store it in data queues."""
 
@@ -463,6 +486,7 @@ class RecordBase:
             recording.save(measurement, file)
         except Exception as error:
             print(f'Data saving error for {recording.name}: {error}')
+            print_exc()
 
     def data_save(self, name):
         """Save data that is stored in a queue by data_read."""
